@@ -2,6 +2,9 @@
 # encoding: utf8
 
 """
+NOTE: You should use wmlparser2.py instead which uses the C++
+preprocessor.
+
 This module represents the internal appearance of WML.
 
 Note: We cannot store textdomain information, due to how the parser work.
@@ -176,7 +179,7 @@ class DataSub(Data):
 
     def write_file(self, f, indent=0, textdomain=""):
         f.write(self.make_string( indent, textdomain))
-        
+
     def make_string(self, indent = 0, textdomain = ""):
         """Write the data object to the given file object."""
         ifdef = 0
@@ -265,6 +268,7 @@ class DataSub(Data):
         for r in result:
             if r != None:
                 # For networking, we need actual bytesteam here, not unicode.
+                if type(r) is unicode: r = r.encode("utf8")
                 bytes += str(r)
 
         return bytes
@@ -493,7 +497,7 @@ class DataSub(Data):
         """Gets all macros matching the name"""
         return [macro for macro in self.get_all(name)
             if isinstance(macro, DataMacro)]
-            
+
     def get_all_macros(self):
         """Gets all macros"""
         return [macro for macro in self.data
